# This is a basic calculator
It can be used to add , subtract , multiple, divide two integers

## Installation
```
pip3 install eb7calculator
```

## Import

```python
from eb7calculator import calculator as calc

# or

from eb7calculator.calculator import add, sub, mul, div

```

## usage
```python
from eb7calculator import calculator as calc

calc.add(1,2)
# output:3

calc.sub(2,1)
# output:1

calc.mul(10,2)
# outout:20

calc.div(10,5)
# output:2.0
```
